call_astrometry — MSUMastro toolbox 0.1 documentation

# call_astrometry

`msumastro.header_processing.astrometry.` `call_astrometry`(filename, sextractor=False, feder_settings=True, no_plots=True, minimal_output=True, save_wcs=False, verify=None, ra_dec=None, overwrite=False, wcs_reference_image_center=True)

  Wrapper around astrometry.net solve-field.

  Parameters: | sextractor : bool or str, optional `True` to use sextractor, or a `str` with the path to sextractor. feder_settings : bool, optional Set True if you want to use plate scale appropriate for Feder Observatory Apogee Alta U9 camera. no_plots : bool, optional `True` to suppress astrometry.net generation of plots (pngs showing object location and more) minimal_output : bool, optional If `True`, suppress, as separate files, output of: WCS header, RA/Dec object list, matching objects list, but see also save_wcs save_wcs : bool, optional If `True`, save WCS header even if other output is suppressed with minimial_output verify : str, optional Name of a WCS header to be used as a first guess for the astrometry fit; if this plate solution does not work the solution is found as though verify had not been specified. ra_dec : list or tuple of float (RA, Dec); also limits search radius to 1 degree. overwrite : bool, optional If `True`, perform astrometry even if astrometry.net files from a previous run are present. wcs_reference_image_center : If `True`, force the WCS reference point in the image to be the image center.